/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*

    Copyright (C) 2012-2014  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Gettext = imports.gettext;
const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Extension = ExtensionUtils.getCurrentExtension();

const Convenience = Extension.imports.convenience;
const PanelTools = Extension.imports.panelTools;

const _ = Gettext.domain(Convenience.CURRENT_GETTEXT_DOMAIN).gettext;

/*
    PanelManager - Accessibility
 */
const StatusArea = Main.panel.statusArea || Main.panel._statusArea;

const KEY_SHOW_ACCESSIBILITY = 'show-accessibility';
const KEY_SHOW_STATUSAREA = 'show-statusarea';

const STATUSAREA_DEFAULT = 0;

function _noScreenReader() {
    let menuItems = StatusArea.a11y.menu._getMenuItems();
    for each(let item in menuItems) {
        if (item.label && item.label.text === Gettext.gettext("Screen Reader")) return false;
    }
    return true;
}

const Accessibility = new Lang.Class({
    Name: 'Accessibility',

    _init: function() {
        if (Convenience.checkGSV(3, 4) && _noScreenReader()) {
            this._itemScreenReader = StatusArea.a11y._buildItem(_("Screen Reader"), 'org.gnome.desktop.a11y.applications', 'screen-reader-enabled');
            StatusArea.a11y.menu.addMenuItem(this._itemScreenReader, 3);
        }
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = [
            this._settings.connect('changed::'+KEY_SHOW_ACCESSIBILITY, Lang.bind(this, this._onShowAccessibility)),
            this._settings.connect('changed::'+KEY_SHOW_STATUSAREA, Lang.bind(this, this._onShowStatusArea))
        ];
        this._onShowAccessibility();
        this._onShowStatusArea();
    },

    _onShowAccessibility: function () {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_ACCESSIBILITY));
    },

    _onShowStatusArea: function() {
        if (this._itemScreenReader) this._itemScreenReader.actor.visible = this._settings.get_enum(KEY_SHOW_STATUSAREA) !== STATUSAREA_DEFAULT;
    },

    _updateVisibility: function(visible) {
        StatusArea.a11y.actor.visible = visible;
    },

    destroy: function() {
        for each(let connection in this._connectSettings) {
            this._settings.disconnect(connection);
        }
        if (this._itemScreenReader) this._itemScreenReader.destroy();
        this._updateVisibility(true);
    }
});

function getExtension() {
    return Convenience.checkGSV(3, 4) || Convenience.checkGSV(3, 6) || Convenience.checkGSV(3, 8) ? new Accessibility() : null;
}
