/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*

    Copyright (C) 2012-2014  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const Clutter = imports.gi.Clutter;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Extension = ExtensionUtils.getCurrentExtension();

const Convenience = Extension.imports.convenience;

/*
    PanelManager - Activities
 */
const KEY_SHOW_ACTIVITIES = 'show-activities';

const Activities = new Lang.Class({
    Name: 'Activities',

    _init: function() {
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_ACTIVITIES, Lang.bind(this, this._onShowActivities));
        this._onShowActivities();
    },

    _onShowActivities: function() {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_ACTIVITIES));
    },

    _setStyleParent: function() {
        if (Main.panel.actor.get_text_direction() === Clutter.TextDirection.RTL) {
            Main.panel._leftCorner.setStyleParent(Main.panel._rightBox);
        } else {
            Main.panel._leftCorner.setStyleParent(Main.panel._leftBox);
        }
    },

    _updateVisibility: function(visible) {
        if (Main.panel._activitiesButton) {
            Main.panel._activitiesButton.actor.visible = visible;
        } else {
            Main.panel.statusArea.activities.container.visible = visible;
            if (Main.panel._leftCorner.setStyleParent) this._setStyleParent();
        }
    },

    destroy: function() {
        this._settings.disconnect(this._connectSettings);
        this._updateVisibility(true);
    }
});

function getExtension() {
    return new Activities();
}
