/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*

    Copyright (C) 2012-2014  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Gettext = imports.gettext;
const Lang = imports.lang;

const St = imports.gi.St;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Extension = ExtensionUtils.getCurrentExtension();

const Convenience = Extension.imports.convenience;
const PanelTools = Extension.imports.panelTools;

const _ = Gettext.domain(Convenience.CURRENT_GETTEXT_DOMAIN).gettext;

/*
    PanelManager - Keyboard
 */
const StatusArea = Main.panel.statusArea || Main.panel._statusArea;

const KEY_SHOW_KEYBOARD = 'show-keyboard';

const PANELMENU_BUTTON_DEFAULT = 0;
const PANELMENU_BUTTON_SHOW = 1;

const Keyboard = new Lang.Class({
    Name: 'Keyboard',

    _init: function() {
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_KEYBOARD, Lang.bind(this, this._onShowKeyboard));
        if (Convenience.checkGSV(3, 4)) {
            this._connectKeyboardConfig = StatusArea.keyboard._config.connect('changed', Lang.bind(this, this._onShowKeyboard));
        } else if (Convenience.checkGSV(3, 6) || Convenience.checkGSV(3, 8) || Convenience.checkGSV(3, 10) || Convenience.checkGSV(3, 12)) {
            this._connectKeyboardSettings = [
                StatusArea.keyboard._settings.connect('changed::current', Lang.bind(this, this._onShowKeyboard)),
                StatusArea.keyboard._settings.connect('changed::sources', Lang.bind(this, this._onShowKeyboard))
            ];
        } else if (Convenience.checkGSV(3, 14)) {
            this._connectKeyboardInputSourceManager = StatusArea.keyboard._inputSourceManager.connect('current-source-changed', Lang.bind(this, this._onShowKeyboard));
        }
        this._onShowKeyboard();
    },

    _onShowKeyboard: function() {
        this._updateVisibility();
        let visible = StatusArea.keyboard.actor.visible;
        let showKeyboard = this._settings.get_enum(KEY_SHOW_KEYBOARD);
        if (showKeyboard !== PANELMENU_BUTTON_DEFAULT) visible = showKeyboard === PANELMENU_BUTTON_SHOW;
        StatusArea.keyboard.actor.visible = visible;
    },

    _updateVisibility: function() {
        if (Convenience.checkGSV(3, 4)) {
            StatusArea.keyboard._syncConfig();
        } else if (Convenience.checkGSV(3, 6) || Convenience.checkGSV(3, 8) || Convenience.checkGSV(3, 10) || Convenience.checkGSV(3, 12)) {
            StatusArea.keyboard._currentInputSourceChanged();
        } else if (Convenience.checkGSV(3, 14)) {
            StatusArea.keyboard._currentSourceChanged();
        }
    },

    destroy: function() {
        if (Convenience.checkGSV(3, 4)) {
            StatusArea.keyboard._config.disconnect(this._connectKeyboardConfig);
        } else if (Convenience.checkGSV(3, 6) || Convenience.checkGSV(3, 8) || Convenience.checkGSV(3, 10) || Convenience.checkGSV(3, 12)) {
            for each(let connection in this._connectKeyboardSettings) {
                StatusArea.keyboard._settings.disconnect(connection);
            }
        } else if (Convenience.checkGSV(3, 14)) {
            StatusArea.keyboard._inputSourceManager.disconnect(this._connectKeyboardInputSourceManager);
        }
        this._settings.disconnect(this._connectSettings);
        this._updateVisibility();
    }
});

function getExtension() {
    return new Keyboard();
}
